@@ -1,6 +1,6 @@
 package CSS::Style;
 
-$VERSION = 1.00;
+$VERSION = 1.01;
 
 use strict;
 use warnings;
@@ -68,6 +68,17 @@ sub to_string {
 	return $adaptor_obj->output_rule($self);
 }
 
+sub get_property_by_name {
+        my ($self, $prop_name) = @_;
+
+        for my $prop (@{$self->{properties}}){
+                if ($prop->{property} eq $prop_name){
+                        return $prop;
+                }
+        }
+        return 0;
+}
+
 1;
 
 __END__
@@ -135,6 +146,11 @@ method.
 This method is used to serialize the ruleset, using the current adaptor. It returns 
 a string which comes from the adaptor's output_rules() method.
 
+=item C<get_property_by_name( 'property_name' )>
+
+Returns the first CSS::Property object with the specified name. Returns
+zero on failure.
+
 =back
 
 =head1 AUTHOR
